@@ -40,7 +40,14 @@ def yolo_eval(yolo_outputs: Dict[str, np.ndarray],
     -------
     Tuple of detected boxes, scores and classes.
     """
-    _yolo_outputs = [yolo_outputs['conv2d_10/BiasAdd:0'], yolo_outputs['conv2d_13/BiasAdd:0']]
+    out_names = list(yolo_outputs.keys())
+    assert yolo_outputs[out_names[0]].shape == (1, 13, 13, 255)
+    assert yolo_outputs[out_names[1]].shape == (1, 26, 26, 255)
+
+    _yolo_outputs = [
+        yolo_outputs[out_names[0]],
+        yolo_outputs[out_names[1]]
+    ]
     out_boxes, out_scores, out_classes = yolo_eval_processing(
         _yolo_outputs,
         TINY_YOLO3_ANCHORS,
