@@ -1,5 +1,5 @@
 """Tensorflow Runner ulils."""
-from typing import List, Dict
+from typing import List, Dict, Any
 import warnings
 
 import numpy as np
@@ -106,3 +106,34 @@ class TFRunnerOld(Runner):
             node_dict = {self.output_nodes[index]: outputs[index]}
             outputs_dict.update(node_dict)
         return outputs_dict
+
+
+def get_original_node_names_from_cfg(conf_tpu_json_dict: Dict[str, Any]) -> Dict[str, str]:
+    """
+    Make a dict with input and output quant nodes names as keys and corresponding original nodes names as values.
+
+    This function uses a dict from to_compile/conf.tpu.json which is obtained after quantization.
+
+    Parameters
+    ----------
+    conf_tpu_json_dict
+        dict from conf.tpu.json file
+
+    Returns
+    -------
+    The dict which matches nodes of quantized graph and original nodes
+    """
+    match_dict = {}
+    in_out_nodes = []
+    comp_dict = conf_tpu_json_dict['model']
+    all_nodes = list(comp_dict.keys())
+    in_out_raw_nodes = [node for node in all_nodes if 'input_node' in node or 'output_node' in node]
+    for node in in_out_raw_nodes:
+        if 'input_node' in node:
+            node = node + '/Placeholder:0'
+        if 'output_node' in node:
+            node = node + '/output:0'
+        in_out_nodes.append(node)
+    for node in in_out_nodes:
+        match_dict[node] = comp_dict[node.split('/')[0]]['tpu_anchor']
+    return match_dict
