@@ -57,7 +57,7 @@ class TPURunner(Runner):
         """
         tensors = tensor_to_op(tensors)
         inference = TPUInference(self._program)
-        inference.load_tensors_dict(tensors)
+        inference.load(tensors)
 
         if self._sync:
             self._device.load_inference_sync(inference)
@@ -65,5 +65,5 @@ class TPURunner(Runner):
             status_future = self._device.load_inference(inference)
             self._loop.run_until_complete(status_future)
 
-        tpu_out_tensors = inference.get_tensors_dict()
+        tpu_out_tensors = inference.get(as_dict=True)
         return op_to_tensor(tpu_out_tensors)
