@@ -27,7 +27,7 @@ def image_to_tensor(image: Image, yolo_size: Tuple[int, int] = (608, 608)) -> np
         raise TypeError(f'img should be {Image.Image} Image. Got {type(image)}')
 
     image = image.convert('RGB')
-    image = np.asarray(image, dtype=np.float32)
+    image = np.asarray(image).astype(np.float32)
     yolo_h, yolo_w = yolo_size
     image_h, image_w, _ = image.shape
 
